#
# spec file for package figlet
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           figlet
Version:        2.2.5
Release:        4.4
Summary:        Tool for Creating Cool ASCII-Art Signatures
License:        BSD-3-Clause
Group:          Productivity/Text/Utilities
URL:            http://www.figlet.org/
# Patched code is built by default.
# Use rpmbuild -D 'BUILD_ORIG 1' to build original code.
%if 0%{?BUILD_ORIG}
Source0:        ftp://ftp.figlet.org/pub/figlet/program/unix/%{name}-%{version}.tar.gz
Source999:      %{name}-%{version}-patched.tar.bz2
%else
# WARNING: This is not a comment, but a real command to repack source:
#%(sh %{_sourcedir}/figlet-licpatch.sh %{_sourcedir})
Source0:        %{name}-%{version}-patched.tar.bz2
Source999:      ftp://ftp.figlet.org/pub/figlet/program/unix/%{name}-%{version}.tar.gz
%endif
Source1:        ftp://ftp.figlet.org/pub/figlet/fonts/contributed.tar.gz
Source2:        ftp://ftp.figlet.org/pub/figlet/fonts/international.tar.gz
Source3:        ftp://ftp.figlet.org/pub/figlet/fonts/ours.tar.gz
Source100:      figlet-licpatch.sh
# PATCH-FIX-OPENSUSE figlet-config.patch -- Fix installation directories
Patch0:         figlet-config.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes

%description
FIGlet can create characters in many different styles and can kern and
"smush" these characters together in various ways. FIGlet output is
generally reminiscent of the sort of "signatures" many people like to
put at the end of e-mail and UseNet messages.

%prep
%setup -q -a 1 -a 2 -a 3
cd contributed
tar -zxf Obanner-canon.tgz
rm Obanner-canon.tgz
tar -zxf Obanner.tgz
rm Obanner.tgz
cd ..
cd international
tar -zxf cjkfonts.tar.gz
rm cjkfonts.tar.gz
cd ..
%patch -P 0

%build
make CFLAGS="%{optflags}" %{?_smp_mflags}

%install
%make_install

# For inclusion in documentation
mv contributed/bdffonts/bdf2flf.pl .
mv international/febrew .

cp -a contributed %{buildroot}%{_datadir}/figlet/
cp -a international %{buildroot}%{_datadir}/figlet/
cp -a ours %{buildroot}%{_datadir}/figlet/

%fdupes -s %{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGES FAQ README figfont.txt
%license LICENSE
%doc bdf2flf.pl febrew
%{_bindir}/chkfont
%{_bindir}/figlet
%{_bindir}/figlist
%{_bindir}/showfigfonts
%{_datadir}/figlet/
%doc %{_mandir}/man6/chkfont.6%{ext_man}
%doc %{_mandir}/man6/figlet.6%{ext_man}
%doc %{_mandir}/man6/figlist.6%{ext_man}
%doc %{_mandir}/man6/showfigfonts.6%{ext_man}

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue May 23 2023 Jiri Srain <jsrain@suse.com>
- adjust .spec-file to list all sources independently on the
  build options
- flag the license properly
* Wed May 31 2017 bwiedemann@suse.com
- delete file from tar without repacking
  to make build reproducible
* Sat Mar 14 2015 benoit.monin@gmx.fr
- update to version 2.2.5:
  * Add regression tests for uskata and jis0201 control files
  * Properly escape minus signs in figlist(6) man page
  * Fix chkfont coredump on invalid input
  * Update ISO8859 map files to fix licensing issue raised in Debian
    bugs 673096 and 674844
  * Re-add missing figmagic and getopt.c files which were left out
    of releases 2.2.3 and 2.2.4
  * Fix output of test script in MacOS X
- remove source figlet222-8859tables.tar.bz2: fixed upstream
- update figlet-licpatch.sh: iso8859 files fixed updtream
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Sat Jul 16 2011 asterios.dramis@gmail.com
- Update to version 2.2.4:
  * Add support to Sam Hocevar's TOIlet TLF fonts containing UTF-8
    encoded Unicode characters.
  * Add infocode 5 to list supported font formats
  * Fix rendering error caused by the previous attempt to fix invalid
    memory accesses when smushing at start of line
  * New environment variable FIGLET_FONTDIR can be used to specify
    the path to search for fonts
  * Add regression tests
  From 2.2.3:
  * License changed from "Academic Free License" to "New BSD License"
    (3-clause) as agreed by FIGlet authors
  * New JIS X 0201 control file (Micah Cowan)
  * Fix behavior of JIS0201 SHIFT-OUT and SHIFT-IN that were previouly
    inverted (Micah Cowan)
  * Fix memory violation when smushing at line start
  * Fix handling of memory allocation errors
  * Relicense Ed Hamrick zipio under the MIT license. This should
    eliminate any concerns about redistribution of FIGlet as libre
    software.
  * Update Makefile to meet modern standards in variable naming, using
    BINDIR as the pathname for binary files and reservind DESTDIR
    as the extra prefix commonly used in package building.
  * Add a Turbo C makefile, just because I had the compiler. (this
    also tests portability to old compilers and foreign platforms)
  * Add Jonathon Abbott's man pages for figlist, showfigfonts and
    chkfont originally contributed to the Debian Project
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to BSD-3-Clause.
  * Install binaries in /usr/bin and fonts in /usr/share/figlet.
  * Minor other updates.
- Rebased figlet-config.patch to apply cleanly.
- Removed figlet-random.patch and figlet-implicit.patch (fixed upstream).
* Mon Mar  7 2011 cdenicolo@novell.com
- license update: AFLv2.1
  license is AFLv2.1
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Thu Jun 21 2007 pcerny@suse.cz
- more update due to [#285171]
* Mon Jun 18 2007 pcerny@suse.cz
- updated some files from unicode.org [#285171]
* Thu Jun 14 2007 pcerny@suse.cz
- changed permissions for showfigfonts and figlist (#281419)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Wed Jul 20 2005 sbrabec@suse.cz
- Updated to version 2.2.2.
* Tue Oct 15 2002 sbrabec@suse.cz
- Update to version 2.2.1.
- Make build root install.
- FHS fixes (use games specific paths).
* Thu Dec  6 2001 ro@suse.de
- install manpage into right place
* Mon Jul 16 2001 rvasice@suse.cz
- fix bug [9215]
* Tue May  8 2001 mfabian@suse.de
- bzip2 some sources
* Sat Dec  9 2000 nashif@suse.de
- sorted
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Apr 20 1998 ray@suse.de
- move to /usr/lib/figlet
* Tue Apr  7 1998 ray@suse.de
- new package figlet V2.2
